clear all; close all; clc
global Theta_0 theta_0 alpha number l mass k_theta 
global Tinput dispU

%% structural parameters
number = 80; %number of umits in the chain
a=0.075; %length of 1 unit
mass=18e-3; %mass of 1 unit
alpha = 0.55; %mass distribution
e = 5.2e-3; % eccentric offset
eps_st = -0.1; % pre-strain

% parameters of the elastic beam
beam_length = 0.05; % length
E_beam=4.3e9; % Young's modulus
h_beam=0.8e-3; % thickness
b_beam=6e-2; % width

%% calculated parameters in model
l = (e^2+a^2/4)^0.5; % length of the rigid rod
theta_0 = atan(2*e/a); % initial angle of rod
Theta_0 = acos(cos(theta_0)*(eps_st+1)); % angle of rod after pre-strain

I_beam=1/12*b_beam*h_beam^3;
k_theta=E_beam*I_beam/beam_length;

%% applied excitations
all_time=0.0075*number; % total simulation times
A = 0.11; % rarefaction wave used in manuscript
% one can change to A = -0.11 to see the response of compression wave.
W = 102.1e-3; % calculated width
c = 9.13; % calculated velocity
Tinput = linspace(0,all_time,1000);
dispU = -A*W + A*W*tanh(-Tinput*c/W+10); % apply Eq.(15)

%% initial conditions
initial=zeros(2*number,1); % set displacement and velocities of each joint to zero

% use mass matrix feature of ode45 to handle 
% coupled second order derivatives.
M = mass_matrix(alpha,number,Theta_0); 
options = odeset('Mass',M); 

%% numerically solve Eq.(5) via ode45
[t,q] = ode45(@right_part,[0,all_time],initial,options);
[Timelength, Distance]=size(q);

%% output
for i = 1:number % extract displacement signals
    q_out(:,i) = q(:,2*i-1);
end
t_array = linspace(0.01,all_time,1000); % slice time points
clf; fig = figure(1);
set(fig,'Position',[0,0,700,400]);
for tt = round(interp1(t,1:length(t),t_array))
    hold off
    q_now = q_out(tt,:);
    % calculate strain distribution at certain time
    strain=zeros(number,1); 
    strain(1:number-1) = diff(q_now)./a/cos(Theta_0);
    % plot strain distributions
    plot(1:number,strain,'-k^','linewidth',0.5,'MarkerFaceColor','M','MarkerSize',8);hold on
    text(0.72*number,abs(A)*1.1,['time=',num2str(t(tt),'%.3f'),'s'],'FontSize',24)
    xlabel('unit number \it i','FontName','Arial','fontsize',28)%x????
    ylabel('strain \epsilon_i','FontName','Arial','fontsize',28)%y????
    set(gca,'FontName','Arial','fontsize',24)%
    xlim([0,number]);ylim([-abs(A),abs(A)].*1.2);
    pause(0.001);
end
close all















